#[non_exhaustive]pub enum EncryptionState {
Default,
KmsEncryptionState(KmsEncryptionState),
#[non_exhaustive] Unknown,
}Expand description
A structure that contains the encryption configuration for the policy store and child resources.
This data type is used as a response parameter field for the GetPolicyStore operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Default
This is the default encryption state. The policy store is encrypted using an Amazon Web Services owned key.
KmsEncryptionState(KmsEncryptionState)
The KMS encryption settings currently configured for this policy store to encrypt data with. It contains the customer-managed KMS key, and a user-defined encryption context.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl EncryptionState
impl EncryptionState
Sourcepub fn as_default(&self) -> Result<(), &Self>
pub fn as_default(&self) -> Result<(), &Self>
Tries to convert the enum instance into Default, extracting the inner ().
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if this is a Default.
Sourcepub fn as_kms_encryption_state(&self) -> Result<&KmsEncryptionState, &Self>
pub fn as_kms_encryption_state(&self) -> Result<&KmsEncryptionState, &Self>
Tries to convert the enum instance into KmsEncryptionState, extracting the inner KmsEncryptionState.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_kms_encryption_state(&self) -> bool
pub fn is_kms_encryption_state(&self) -> bool
Returns true if this is a KmsEncryptionState.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.